/**********************************************************************

	FLASHFAT.C
	Z-World, 2002

	This program demonstrates a basic interface to read and write to an
	existing file on a standard PCMCIA flash disk with a PC file system
	set up in a particular manner.  See Tech Note TN222 for a more
	detailed description, including how to connect the PCMCIA device
	to the Rabbit 3000 and how to format the flash disk.

	NOTE that you will need to run FINDFIRSTSECTOR.C to provide
	the correct starting sector of your file.
	
 **********************************************************************/

#use "atainterface.lib"

/**********************************************************************/

void setupRabbit()
{
	// enable the alternate I/O bus for read/writes with IOE prefix
	enableIObus();

	// initialize port E pins

	WrPortI(PEDR, &PEDRShadow, 0x01);	// set PE0 high
	WrPortI(PEDDR, &PEDDRShadow, 0x01);	// set PE0 as an output

	WrPortI(PEFR, &PEFRShadow, 0x01);	// enable I/O strobe on PE0
	WrPortI(IB0CR, &IB0CRShadow, 0xC8);	// PE0 is a chip select strobe
}

/**********************************************************************
	main
 **********************************************************************/

//
// NOTE: this value will vary from device to device!  Run
// the FINDFIRSTSECTOR.C program first to determine the proper
// value for your flash disk.
//
 
#define	STARTING_SECTOR	85

 
main()
{
	char	buf[512];
	int	i, j;
		

	setupRabbit();
	ataInit();

	
	for (i=0; i<10; i++) {
		memset(buf, 0x00, 512);
		sprintf(buf, "This is sector %d -- timestamp=%ld", i, MS_TIMER);
		ataWriteSector(STARTING_SECTOR + i, buf);
	}

	printf("Write completed.  Now insert the flash disk into your\n");
	printf("PC and examine the data file.\n");
}
